{ config, pkgs, lib, ... }:

{
  imports =
    [
      ./hardware-configuration.nix

      ./fieldpoc.nix
    ];

  boot.kernelParams = [ "console=ttyS0,115200n8" ];

  boot.loader.grub.enable = true;
  boot.loader.grub.version = 2;
  boot.loader.grub.device = "/dev/sda";
  boot.loader.grub.extraConfig = "
    serial --speed=115200 --unit=0 --word=8 --parity=no --stop=1
    terminal_input serial
    terminal_output serial
  ";

  networking.hostName = "aluminium";

  networking.iproute2.enable = true;
  networking.iproute2.rttablesExtraConfig = ''
    200 wg-clerie
  '';

  petabyte.policyrouting = {
    enable = true;
    rules6 = [
      { rule = "from 2a01:4f8:c0c:15f1::8106/128 lookup wg-clerie"; prio = 20000; }
      { rule = "from 2a01:4f8:c0c:15f1::8106/128 unreachable"; prio = 20001; }
    ];
    rules4 = [
      { rule = "from 10.20.30.106/32 lookup wg-clerie"; prio = 20000; }
      { rule = "from 10.20.30.106/32 unreachable"; prio = 20001; }
    ];
  };


  networking.wireguard.enable = true;
  networking.wireguard.interfaces = {
    wg-clerie = {
      ips = [ "2a01:4f8:c0c:15f1::8106/128" "10.20.30.106/32" ];
      table = "wg-clerie";
      peers = [
        {
          endpoint = "vpn.clerie.de:51820";
          persistentKeepalive = 25;
          allowedIPs = [ "0.0.0.0/0" "::/0" "10.20.30.0/24" "2a01:4f8:c0c:15f1::/113" ];
          publicKey = "2p1Jqs3bkXbXHFWE6vp1yxHIFoUaZQEARS2nJzbkuBA=";
        }
      ];
      privateKeyFile = "/var/src/secrets/wireguard/wg-clerie";
    };
  };

  clerie.monitoring = {
    enable = true;
    id = "212";
    pubkey = "P1ONelxezvkcLJFyvuCVeIUd3uewPIlONfKk9y6h9QE=";
    serviceLevel = "event";
    privateKeyFile = "/var/src/secrets/wireguard/wg-monitoring";
  };

  system.stateVersion = "22.11";
}
