{ config, pkgs, lib, ... }:

{
  imports =
    [
      ./hardware-configuration.nix
      ../../configuration/proxmox-vm
      ../../configuration/dn42
    ];

  boot.loader.grub.enable = true;
  boot.loader.grub.version = 2;
  boot.loader.grub.device = "/dev/vda";

  networking.hostName = "dn42-il-gw5";

  networking.useDHCP = false;
  # VM Nat Netz mercury
  networking.interfaces.ens18.ipv4.addresses = [ { address = "192.168.10.25"; prefixLength = 24; } ];
  # OSPF Netz
  networking.interfaces.ens19 = {};
  # Lokales Netz
  networking.interfaces.ens20.ipv6.addresses = [ { address = "fd56:4902:eca0:5::1"; prefixLength = 64; } ];
  # IPv6 Uplink
  networking.interfaces.ens21.ipv6.addresses = [ { address = "2001:638:904:ffc9::a"; prefixLength = 64; } ];
  # Ildix
  networking.interfaces.ens22.ipv6.addresses = [ { address = "fd81:edb3:71d8:ffff:2574::5"; prefixLength = 64; } ];

  networking.defaultGateway = { address = "192.168.10.1"; interface = "ens18"; };
  networking.defaultGateway6 = { address = "2001:638:904:ffc9::1"; interface = "ens21"; };
  networking.nameservers = [ "2001:638:904:ffcc::3" "2001:638:904:ffcc::4" "141.24.40.3" "141.24.40.4" ];

  petabyte.policyrouting = {
    enable = true;
    rules6 = [
      { rule = "from all to fd56:4902:eca0::/48 lookup 1337"; prio = 10000; }
      { rule = "from all to all lookup 2342"; prio = 10000; }
      { rule = "from all to fd56:4902:eca0::/48 unreachable"; prio = 20000; }
      { rule = "from fd56:4902:eca0::/48 to all unreachable"; prio = 20000; }
    ];
  };

  services.bird2.enable = true;
  services.bird2.config = ''
  router id ${ (lib.head config.networking.interfaces.ens18.ipv4.addresses).address };

  ipv6 table ospf6;
  ipv6 table bgp6;

  protocol direct {
    interface "ens20";
    ipv6 {
      table ospf6;
    };
  }

  protocol static {
          ipv6 {
                  table bgp6;
          };
          route fd56:4902:eca0::/48 via "lo";
          route fd56:4902:eca0::/52 via "lo";
  }

  protocol kernel {
    ipv6 {
      table ospf6;
      export filter {
        krt_prefsrc=fd56:4902:eca0:5::1;
        accept;
      };
      import none;
    };
    kernel table 1337;
  }

  protocol kernel {
          ipv6 {
                  table bgp6;
                  export filter {
                          krt_prefsrc=fd56:4902:eca0:5::1;
        accept;
                  };
                  import none;
          };
    kernel table 2342;
  }

  protocol ospf v3 {
    ipv6 {
      table ospf6;
      import all;
      export all;
    };
    area 0 {
      interface "ens19" {
        cost 80;
        type broadcast;
      };
    };
  }

  protocol bgp gw1 {
          local as 4242422574;
          graceful restart on;
          neighbor fd56:4902:eca0:1::1 as 4242422574;
          source address fd56:4902:eca0:5::1;
          ipv6 {
                  table bgp6;
                  igp table ospf6;
                  next hop self;
                  import keep filtered;
                  import all;
                  export all;
          };
  }

  protocol bgp gw6 {
          local as 4242422574;
          graceful restart on;
          neighbor fd56:4902:eca0:6::1 as 4242422574;
          source address fd56:4902:eca0:5::1;
          ipv6 {
      table bgp6;
      igp table ospf6;
                  next hop self;
                  import keep filtered;
                  import all;
                  export all;
          };
  }

  template bgp ildix {
    local as 4242422574;
    graceful restart on;
    source address fd81:edb3:71d8:ffff:2574::5;
    ipv6 {
      table bgp6;
      igp table ospf6;
      next hop self;
      import keep filtered;
      import filter {
        if net ~ [fd00::/8{8,64}] then accept;
        reject;
      };
      export filter {
        if net ~ [fd00::/8{8,64}] then accept;
        reject;
      };
    };
  }

  protocol bgp peer_ildix_clerie from ildix {
    neighbor fd81:edb3:71d8:ffff::13 as 4242422953;
  }

  protocol bgp peer_ildix_nex from ildix {
    neighbor fd81:edb3:71d8:ffff::14 as 4242422953;
  }

  protocol device {
    scan time 10;
  }
  '';

  clerie.monitoring = {
    enable = true;
    id = "305";
    pubkey = "DRJ4FFqNCRgxzmD+k4WKVKJiKKTxTm5Uupcz04j1Ag8=";
    bird = true;
  };

  system.stateVersion = "21.03";
}
